#!/bin/bash
#
# Intel VCA Software Stack (VCASS)
#
# Copyright(c) 2016 Intel Corporation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# The full GNU General Public License is included in this distribution in
# the file called "COPYING".
#
# Intel VCA Scripts.
#
unset LANG
export VCA_CHECKSUMSFILE=sha1_checksums.txt

show_help() {
    if [ $# == 0 ] || [[ $# > 1 ]] || [ $1 == "-h" ] || [ $1 == "--help" ] ; then
        echo -e "\nGenerate all available images"
        echo -e "\t<build_version> - optional version, which will be appended to all image names"
        echo -e "\t--os-repo <path>	Repository containing rpms from CentOS image"
        echo -e "\t--extras-repo <path>	Repository containing extra rpms, out of build (like additional, 3rd party validation tools)"
        echo -e "\t--build-repo <path>	Repository containing rpms from the build"
    fi
}

# Default repositories locations
if [ "$VCA_OS_REPO" == "" ];then
    export VCA_OS_REPO="file:/usr/lib/vca/repos/CentOS7.4/os_repo"
fi
if [ "$VCA_EXTRAS_REPO" == "" ];then
    export VCA_EXTRAS_REPO="file:/usr/lib/vca/repos/CentOS7.4/extras_repo"
fi
if [ "$VCA_BUILD_REPO" == "" ];then
    export VCA_BUILD_REPO="file:/usr/lib/vca/repos/build_repo"
fi

#
# Uncomment and edit the following lines to use custom locations for repositories
# (custom locations may be also passed as parameter to script or external export definition)
#
# Uncomment and edit to use other location for local base CentOS repo (for example- mount point for DVD)
#export VCA_OS_REPO="file:/usr/lib/vca/repos/CentOS7.1/os_repo"
# Uncomment the following to install CentOS packages from Internet instead from local repo
#export VCA_OS_REPO="http://centos.crazyfrogs.org/7.1.1503/os/x86_64/"
# Uncomment and edit to use other location for extra packages repo (not stock CentOS and not VCASS build)
#export VCA_EXTRAS_REPO="file:/usr/lib/vca/repos/CentOS7.1/extras_repo"
# Uncomment and edit to use other location of repo containing packages delivered with VCASS build
#export VCA_BUILD_REPO="file:/usr/lib/vca/repos/build_repo"

parse_parameters () {
    if [ "$1" == "-h" ] || [ "$1" == "--help" ] ; then
        show_help
        exit 0
    fi

    while [ "$1" != "" ]
    do
        case "$1" in
            --os-repo)
                export VCA_OS_REPO="$2"
                shift
                shift
                ;;
            --extras-repo)
                export VCA_EXTRAS_REPO="$2"
                shift
                shift
                ;;
            --build-repo)
                export VCA_BUILD_REPO="$2"
                shift
                shift
                ;;
            -h)
                show_help
                exit 0
                ;;
            --help)
                show_help
                exit 0
                ;;
            *)
                export VCA_VERSION_NAME=$1
                shift
                ;;
        esac
    done
}

export VCA_VERSION_NAME=$1
export VCA_OUT_DIR=out
export VCA_TMP_DIR=tmp

parse_parameters "$@"

echo -e "\nPrepare output directory (cleanup/create)"
rm -rf $VCA_OUT_DIR
mkdir $VCA_OUT_DIR

export VCA_IMG_TYPE=volatile-bm
export VCA_ISO_IMG=vca_baremetal
export VCA_GRUB_CFG=grub_cfgs/grub_reference_baremetal.cfg
export VCA_KS_FILE=ks_files/vv_reference_baremetal.ks

# Generate Baremetal image
bash ./generate_vca_image.sh
if [ $? -ne 0 ]; then
    exit 1
fi

export VCA_IMG_TYPE=persistent-bm
export VCA_ISO_IMG=vca_persistent
export VCA_GRUB_CFG=grub_cfgs/grub_reference_persistent.cfg
export VCA_KS_FILE=ks_files/vv_reference_persistent.ks

# Generate Persistent FS boot image
bash ./generate_vca_image.sh
if [ $? -ne 0 ]; then
    exit 1
fi

export VCA_IMG_TYPE=volatile-dom0
export VCA_ISO_IMG=vca_xen
export VCA_GRUB_CFG=grub_cfgs/grub_reference_dom0.cfg
export VCA_KS_FILE=ks_files/vv_reference_dom0.ks

# Generate Xen Dom0 image
bash ./generate_vca_image.sh
if [ $? -ne 0 ]; then
    exit 1
fi

export VCA_IMG_TYPE=domu
export VCA_ISO_IMG=vca_domu
export VCA_GRUB_CFG=grub_cfgs/grub_reference_domu.cfg
export VCA_KS_FILE=ks_files/vv_reference_domu.ks

# Generate Xen DomU image
bash ./generate_vca_image.sh
if [ $? -ne 0 ]; then
    exit 1
fi

echo -e "\nCount image checksums\n"
cd $VCA_OUT_DIR
for file in ./*
do
    sha1sum $file >> $VCA_CHECKSUMSFILE
done
cd ..

echo -e "\nFinished generating images"
